@@ -1,5 +1,5 @@
 """
-Open Generation, Storage, and Transmission Operation and Expansion Planning Model with RES and ESS (openTEPES) - January 12, 2023
+Open Generation, Storage, and Transmission Operation and Expansion Planning Model with RES and ESS (openTEPES) - February 15, 2023
 """
 
 import time
@@ -20,9 +20,10 @@ def openTEPES_run(DirName, CaseName, SolverName, pCompleteResults, pIndLogConsol
     _path = os.path.join(DirName, CaseName)
 
     #%% replacing string values by numerical values
-    idxDict = dict()
+    idxDict        = dict()
     idxDict[0    ] = 0
     idxDict[0.0  ] = 0
+    idxDict[0.0  ] = 0
     idxDict['No' ] = 0
     idxDict['NO' ] = 0
     idxDict['no' ] = 0
@@ -35,10 +36,10 @@ def openTEPES_run(DirName, CaseName, SolverName, pCompleteResults, pIndLogConsol
     idxDict['y'  ] = 1
 
     #%% model declaration
-    mTEPES = ConcreteModel('Open Generation, Storage, and Transmission Operation and Expansion Planning Model with RES and ESS (openTEPES) - Version 4.9.0 - January 12, 2023')
+    mTEPES = ConcreteModel('Open Generation, Storage, and Transmission Operation and Expansion Planning Model with RES and ESS (openTEPES) - Version 4.10.0 - February 15, 2023')
 
-    pCompleteResults = [j for i, j in idxDict.items() if i == pCompleteResults][0]
-    pIndLogConsole   = [j for i, j in idxDict.items() if i == pIndLogConsole  ][0]
+    pCompleteResults = [j for i,j in idxDict.items() if i == pCompleteResults][0]
+    pIndLogConsole   = [j for i,j in idxDict.items() if i == pIndLogConsole  ][0]
 
     # Define sets and parameters
     InputData(DirName, CaseName, mTEPES, pIndLogConsole)
@@ -101,7 +102,6 @@ def openTEPES_run(DirName, CaseName, SolverName, pCompleteResults, pIndLogConsol
         FlexibilityResults    (DirName, CaseName, mTEPES, mTEPES)
         ReliabilityResults    (DirName, CaseName, mTEPES, mTEPES)
 
-
     TotalTime = time.time() - InitialTime
     print('Total time                             ... ', round(TotalTime), 's')
 
